@@ -2,9 +2,12 @@ from .entity import Entity
 from .comment import getComments, addCommentWithFile
 from .tag import tag, getAttachedTags
 from .permissions import getPermissions, newPermission, transferOwnership
+from .sharelink import getSharelink
 
 
 class PrimaryEntity(Entity):
+    __hasParentGroup__ = True
+
     def addComment(self, body, filepath=None, extraParams={}):
         """
         Add a comment and/or file to a Labstep Entity.
@@ -107,6 +110,17 @@ class PrimaryEntity(Entity):
         """
         return getPermissions(self)
 
+    def getSharelink(self):
+        """
+        Returns a sharelink for the Entity.
+
+        Returns
+        -------
+        :class:`~labstep.sharelink.Sharelink`
+            The sharelink for the entity
+        """
+        return getSharelink(self)
+
     def shareWith(self, workspace_id, permission='view'):
         """
         Shares the Entity with another Workspace.
