@@ -11,7 +11,7 @@ import urllib.parse
 
 from .config import API_ROOT
 from .entity import Entity
-from .helpers import url_join, handleError
+from .helpers import url_join, handleError, getHeaders
 from .experiment import getExperiment, getExperiments, newExperiment
 from .protocol import getProtocol, getProtocols, newProtocol
 from .resource import getResource, getResources, newResource
@@ -657,7 +657,7 @@ class User(Entity):
 
     # newEntity()
 
-    def newExperiment(self, name, description=None, extraParams={}):
+    def newExperiment(self, name, entry=None, extraParams={}):
         """
         Create a new Labstep Experiment.
 
@@ -665,8 +665,8 @@ class User(Entity):
         ----------
         name (str)
             Give your Experiment a name.
-        description (str)
-            Give your Experiment a description.
+        entry (obj)
+            A JSON object representing the state of the Experiment Entry.
 
         Returns
         -------
@@ -677,12 +677,10 @@ class User(Entity):
         -------
         ::
 
-            entity = user.newExperiment(name='The Synthesis of Aspirin',
-                                        description='Aspirin is an analgesic
-                                        used to reduce pain.')
+            entity = user.newExperiment(name='The Synthesis of Aspirin')
         """
         return newExperiment(self, name,
-                             description=description,
+                             entry=entry,
                              extraParams=extraParams)
 
     def newProtocol(self, name, extraParams={}):
@@ -878,3 +876,24 @@ class User(Entity):
             entity = user.newFile('./structure_of_aspirin.png')
         """
         return newFile(self, filepath, extraParams=extraParams)
+
+    def acceptSharelink(self, token):
+        """
+        Accept a sharelink
+        Parameters
+        ----------
+        token (class)
+            The token of the sharelink.
+
+        Returns
+        -------
+        None
+        """
+        headers = getHeaders(self)
+        url = url_join(API_ROOT, "/api/generic/",
+                       'share-link')
+        params = {'token': token,
+                  'get_single': 1}
+        r = requests.get(url, headers=headers, params=params)
+        handleError(r)
+        return None
